==> checker-3.49.3.jar: annotated-jdk/src/java.security.jgss/share/classes/org/ietf/jgss/GSSCredential.java <==
/*
 * Copyright (c) 2000, 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.ietf.jgss;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;

public interface GSSCredential extends Cloneable {

    public static final int INITIATE_AND_ACCEPT;

    public static final int INITIATE_ONLY;

    public static final int ACCEPT_ONLY;

    public static final int DEFAULT_LIFETIME;

    public static final int INDEFINITE_LIFETIME;

    public void dispose() throws GSSException;

    public GSSName getName() throws GSSException;

    public GSSName getName(Oid mech) throws GSSException;

    public int getRemainingLifetime() throws GSSException;

    public int getRemainingInitLifetime(Oid mech) throws GSSException;

    public int getRemainingAcceptLifetime(Oid mech) throws GSSException;

    public int getUsage() throws GSSException;

    public int getUsage(Oid mech) throws GSSException;

    public Oid[] getMechs() throws GSSException;

    public void add(GSSName name, int initLifetime, int acceptLifetime, Oid mech, int usage) throws GSSException;

    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object another);

    public int hashCode();
}

==> checker-3.53.0.jar: annotated-jdk/src/java.security.jgss/share/classes/org/ietf/jgss/GSSCredential.java <==
/*
 * Copyright (c) 2000, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.ietf.jgss;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;

public interface GSSCredential extends Cloneable {

    int INITIATE_AND_ACCEPT;

    int INITIATE_ONLY;

    int ACCEPT_ONLY;

    int DEFAULT_LIFETIME;

    int INDEFINITE_LIFETIME;

    void dispose() throws GSSException;

    GSSName getName() throws GSSException;

    GSSName getName(Oid mech) throws GSSException;

    int getRemainingLifetime() throws GSSException;

    int getRemainingInitLifetime(Oid mech) throws GSSException;

    int getRemainingAcceptLifetime(Oid mech) throws GSSException;

    int getUsage() throws GSSException;

    int getUsage(Oid mech) throws GSSException;

    Oid[] getMechs() throws GSSException;

    void add(GSSName name, int initLifetime, int acceptLifetime, Oid mech, int usage) throws GSSException;

    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    boolean equals(@Nullable Object another);

    int hashCode();
}
